Learn R Programming

mixsqp (version 0.3-54)

mixsqp-package: mixsqp: Sequential Quadratic Programming for Fast Maximum-Likelihood Estimation of Mixture Proportions

Description

Provides optimization algorithms based on sequential quadratic programming (SQP) for maximum likelihood estimation of the mixture proportions in a finite mixture model where the component densities are known. To learn more, visit https://github.com/stephenslab/mixsqp, and see the help for function mixsqp.

Arguments