Learn R Programming

mixsqp (version 0.3-54)

tacks: Beckett & Diaconis tack rolling example.

Description

This data set contains the likelihood matrix and weights for the Beckett-Diaconis tacks example, in which the data are modeled using a binomial mixture. These data were generated by running the "Bmix1" demo from the REBayes package, and saving the arguments passed to KWDual, as well as the (normalized) solution returned by the KWDual call.

Arguments

Format

tacks is a list with the following elements:

L

9 x 299 likelihood matrix.

w

Numeric vector of length 9 specifying the weights associated with the rows of L.

x

Solution provided by the KWDual solver.

Examples

Run this code

# The optimal solution for the tack example is extremely sparse.
data(tacks)
plot(tacks$x,type = "l",col = "royalblue")

Run the code above in your browser using DataLab